#!/bin/sh

REMOTEIT_DIR=/usr/share/remoteit
INSTALL_API=https://install.remote.it/v1
CONFIG_FILE=/etc/remoteit/config.json
REGISTRATION=/etc/remoteit/registration

VERSION=$(cat $REMOTEIT_DIR/version.txt)

. $REMOTEIT_DIR/procd.sh
. $REMOTEIT_DIR/oem.sh

r3_update_config() {
  r3_logger "Updating remote.it configuration."

  local config

  if [ -f $CONFIG_FILE ]; then
    config=$(cat $CONFIG_FILE)
  elif [ -f $REGISTRATION ]; then
    local registration=$(cat $REGISTRATION)

    [ -n "$registration" ] || return 0

    config=$(jq -n --arg registration "$registration" '{$registration}')
  else
    config='{}'
  fi

  jq -n \
    --argjson config "$config" \
    --arg name "$(r3_get_name)" \
    --arg identity "$(r3_get_identity)" \
    --argjson manufacturer "$(r3_get_manufacturer)" \
    --argjson platform "$(r3_get_platform)" \
    --argjson metadata "$(r3_get_metadata)" \
    '$config * {$name, $identity, $manufacturer, $platform, $metadata}' | curl -sfo $CONFIG_FILE -d @- $INSTALL_API/refresh
}

r3_update_instances() {
  r3_update_config

  r3_add_schannel

  if [ -r $CONFIG_FILE ]; then
    for id in $(jq -r '.device,.services[] | .id' "$CONFIG_FILE"); do
      r3_add_instance "$id"
    done
  fi
}

r3_get_claim() {
  local claim

  [ -r $CONFIG_FILE ] && claim=$(jq -er '.device.claim' "$CONFIG_FILE") && echo "$claim"
}

r3_error() {
  r3_logger -s "Error: $*" && exit 1
}

r3_install_agent() {
  r3_logger "Installing remote.it agent."

  mkdir -p /etc/remoteit

  if [ ! -x /usr/share/remoteit/connectd ]; then
    r3_logger "Installing remote.it package."

    local arch=$(r3_get_architecture)

    [ -n "$arch" ] || r3_error "Unable to determine architecture."

    local url=https://downloads.remote.it/openwrt/v4.13.0/$arch/binaries.tgz

    curl -sfo- "$url" | tar xzf - -C $REMOTEIT_DIR 2>/dev/null || r3_error "Unknown architecture \"$arch\"."
  fi

  ln -sf $REMOTEIT_DIR/task_notify.sh /usr/bin/connectd_task_notify

  /etc/init.d/remoteit enable
  /etc/init.d/remoteit start

  local code=$(r3_get_claim)

  if [ -n "$code" ]; then
    echo
    echo "--------------------- Claim this device ---------------------"
    echo
    echo "Use the code $code to register this device to your account"
    echo
    echo "--------------------- Claim this device ---------------------"
    echo
  fi
}

r3_remove_agent() {
  r3_logger "Removing remote.it agent."

  /etc/init.d/remoteit stop
  /etc/init.d/remoteit disable

  rm -f /usr/bin/connectd_task_notify
}

r3_reload_agent() {
  /etc/init.d/remoteit reload
}

r3_task_notify() {
  echo "200 OK"
}
